@@ -5,3 +5,5 @@ from sdcclient._secure import SdSecureClient
 from sdcclient._secure_v1 import SdSecureClientV1
 from sdcclient._scanning import SdScanningClient
 from sdcclient.ibm_auth_helper import IbmAuthHelper
+import sdcclient.secure
+import sdcclient.monitor
\ No newline at end of file
